@@ -3,13 +3,20 @@ mod config;
 mod convert;
 mod owner_leak;
 mod resp_error;
+mod resp_extra;
 mod resp_result;
 
 use config::InnerConfig;
 pub use config::{ConfigTrait, DefaultConfig, RespConfig, SerdeConfig};
 pub use convert::{IntoRespResult, IntoRespResultWithErr};
 pub use resp_error::RespError;
-pub use resp_result::{RespResult,Nil};
+#[cfg(feature = "extra-resp")]
+pub use resp_extra::{AdHoc, ExtraWrap};
+pub use resp_extra::{ExtraRespExt, RespExtra};
+pub use resp_result::{Nil, RespResult};
+
+#[cfg(all(feature = "for-actix", feature = "for-axum"))]
+compile_error!("`for-actix` and `for-axum` can not use at the some time");
 
 static RESP_RESULT_CONFIG: state::Storage<InnerConfig> = state::Storage::new();
 
@@ -28,8 +35,7 @@ pub(crate) fn get_config() -> &'static InnerConfig {
     } else {
         #[cfg(feature = "log")]
         logger::warn!("未配置RespResult 配置文件，将使用默认配置");
-        let cfg = RESP_RESULT_CONFIG.get_or_set(Default::default);
-        cfg
+        RESP_RESULT_CONFIG.get_or_set(Default::default)
     }
 }
 
